// (c) Copyright 2011-2012 Cloudera, Inc. All rights reserved.
define([
  'cloudera/cmf/wizard/express/ExpressAddHostsWizard',
  'underscore'
], function(ExpressAddHostsWizard, _) {
  describe("ExpressAddHostsWizard Tests", function() {
    var id = "expressionWizard", module;

    beforeEach(function() {
      $("<div>").attr("id", id).appendTo(document.body);
      var stepIds = [
        'repositorySelectionStep',
        'hostCredentialsStep',
        'installStep',
        'hostInspectorStep',
        'clusterCreationStep',
        'parcelInstallStep'
      ];
      _.each(stepIds, function(stepId) {
        $("<div>").attr("id", stepId).appendTo($("#" + id));
      });
      jasmine.Ajax.useMock();
      clearAjaxRequests();
    });

    afterEach(function() {
      module.unsubscribe();
      $("#" + id).remove();
    });

    it("should initialize an ExpressAddHostsWizard", function() {
      var options = {
        container: "dontcare",
        exitUrl: "dontcare",
        hostInspectorJsonUrl: "dontcare",
        newHosts: ["newHost1"],
        existingHosts: ["existingHost1"]
      };
      module = new ExpressAddHostsWizard(options);
      expect(module.wizard.steps.length).toEqual(6);
    });

    it("should initialize an ExpressAddHostsWizard in resumed state", function() {
      var options = {
        container: "dontcare",
        exitUrl: "dontcare",
        hostInspectorJsonUrl: "dontcare",
        newHosts: ["newHost1"],
        existingHosts: ["existingHost1"],
        resumeState: {
          hasNewHosts: true,
          hostInstallUrl: "dontcare",
          installedHosts: false,
          createdCluster: false,
          installedParcels: false,
          inspectedHosts: false,
          parcels: [],
          cluster: {},
          hosts: ["newHost1"],
          installMethod: "usePackage",
          cdhVersion: 4
        }
      };
      module = new ExpressAddHostsWizard(options);
      expect(module.wizard.steps.length).toEqual(4);
    });

    it("should initialize an ExpressAddHostsWizard in resumed state but hosts are already installed", function() {
      var options = {
        container: "dontcare",
        exitUrl: "dontcare",
        hostInspectorJsonUrl: "dontcare",
        newHosts: ["newHost1"],
        existingHosts: ["existingHost1"],
        resumeState: {
          hasNewHosts: true,
          hostInstallUrl: "dontcare",
          installedHosts: true,
          createdCluster: false,
          installedParcels: false,
          inspectedHosts: false,
          parcels: [],
          cluster: {},
          hosts: ["newHost1"],
          installMethod: "usePackage",
          cdhVersion: 4
        }
      };
      module = new ExpressAddHostsWizard(options);
      expect(module.wizard.steps.length).toEqual(3);
    });

    it("should initialize an ExpressAddHostsWizard in resumed state but hosts are already installed, cluster created", function() {
      var options = {
        container: "dontcare",
        exitUrl: "dontcare",
        hostInspectorJsonUrl: "dontcare",
        newHosts: ["newHost1"],
        existingHosts: ["existingHost1"],
        resumeState: {
          hasNewHosts: true,
          hostInstallUrl: "dontcare",
          installedHosts: true,
          createdCluster: true,
          installedParcels: false,
          inspectedHosts: false,
          parcels: [],
          cluster: {},
          hosts: ["newHost1"],
          installMethod: "usePackage",
          cdhVersion: 4
        }
      };
      module = new ExpressAddHostsWizard(options);
      expect(module.wizard.steps.length).toEqual(2);
    });

  });
});
